function merge(tbls)
	local res = {}
	for i,v in ipairs(tbls) do
		for i2,v2 in ipairs(v) do
			table.insert(res,v2)
		end
	end
	
	return res
end

function allExcept(tbls, except)
	local tomerge = {}
	for i,v in pairs(tbls) do
		if i~=except then
			table.insert(tomerge, v)
		end
	end
	return merge(tomerge)
end

--list of upgrades from created groups, hidden on planner, mfd; late activation
upgrades = {
	smallAirfield = {
		blue = {'blueAifDef1','blueArmor1','blueInfantry','blueInfantry1','blueLightArmor1','blueArmor2','blueArty'},
		red = {'redAifDef1','redArmor1','redInfantry','redInfantry1','redLightArmor1','redArmor2','redArty'}
	},
	largeAirfield = {
		blue = {'blueAifDef1','blueArmor1','blueInfantry','blueInfantry1','blueLightArmor1','blueAirDef2','blueArmor2','blueArty','blueInfantry2','blueLightArmor2'},
		red = {'redAifDef1','redArmor1','redInfantry','redInfantry1','redLightArmor1','redAirDef2','redArmor2','redArty','redInfantry2','redLightArmor2'}
	},
	smallSAMSite = {
		blue = {'blueSmallSam','blueAirDef2','blueArmor2','blueInfantry2','blueLightArmor1'},
		red = {'redSmallSam','redAirDef2','redArmor2','redInfantry2','redLightArmor1'}
	},
	largeSAMSite = {
		blue = {'blueLargeSam','blueAifDef1','blueAirDef2','blueArmor1','blueInfantry','blueLightArmor2','blueInfantry2'},
		red = {'redLargeSam','redAifDef1','redAirDef2','redArmor1','redInfantry','redLightArmor2','redInfantry2'}
	},
	camp = {
		blue = {'blueAifDef1','blueArty','blueArmor1','blueInfantry','blueInfantry1','blueLightArmor1','blueAirDef2','blueArmor2','blueArty','blueInfantry2','blueLightArmor2'},
		red = {'redArty','redAifDef1','redArmor1','redInfantry','redInfantry1','redLightArmor1','redAirDef2','redArmor2','redArty','redInfantry2','redLightArmor2'}
	}
}

--list of waypoints with specific data for specials
flavor = {
	erbilintlairport = 'WPT 1\nStart zone',
	bashurairport = 'WPT 2\nHidden Easter Egg, destroy for 500 immediate credits',
	qayyarahairfieldwest = 'WPT 3\n',
	k1base = 'WPT 4\nHidden Easter Egg, destroy for 500 immediate credits',
	kirkukintlairport = 'WPT 5\n',
	sulaimaniyahintlairport = 'WPT 6\n',
	alsahraairport = 'WPT 7\n',
	camptiliyadeve = 'WPT 8\n',
	baladairbase = 'WPT 9\n',
	alasadairbase = 'WPT 10\n',
	altajiairport = 'WPT 11',
	altaquddumairport = 'WPT 12\n',
	alsalamairbase = 'WPT 13\n',
	baghdadintlairport = 'WPT 14\n',
}

--persistence data
local filepath = 'Raiders_696CW_Iraq_FAFO_Foothold.miz'
if lfs then 
	local dir = lfs.writedir()..'Missions/Saves/'
	lfs.mkdir(dir)
	filepath = dir..filepath
	env.info('Foothold - Save file path: '..filepath)
end

pathofFile = filepath

--list of zones with who owns them starting off and their level of items: 0 = neutral, 1 = red, 2 = blue
bc = BattleCommander:new(filepath, 10, 60)
zones = {
	erbilintlairport = ZoneCommander:new({zone='Erbil Intl Airport', side=2, level=7, upgrades=upgrades.largeSAMSite, crates={}, flavorText=flavor.erbilintlairport}),
	bashurairport = ZoneCommander:new({zone='Bashur Airport', side=1, level=7, upgrades=upgrades.smallAirfield, crates={}, flavorText=flavor.bashurairport}),
	qayyarahairfieldwest = ZoneCommander:new({zone='Qayyarah Airfield West', side=1, level=8, upgrades=upgrades.largeAirfield, crates={}, flavorText=flavor.qayyarahairfieldwest}),
	k1base = ZoneCommander:new({zone='K1 Base', side=1, level=5, upgrades=upgrades.smallAirfield, crates={}, flavorText=flavor.k1base}),
	kirkukintlairport = ZoneCommander:new({zone='Kirkuk Intl Airport', side=1, level=4, upgrades=upgrades.smallSAMSite, crates={}, flavorText=flavor.kirkukintlairport}),
	sulaimaniyahintlairport = ZoneCommander:new({zone='Sulaimaniyah Intl Airport', side=1, level=4, upgrades=upgrades.smallAirfield, crates={}, flavorText=flavor.sulaimaniyahintlairport}),
	alsahraairport = ZoneCommander:new({zone='Al-Sahra Airport', side=1, level=4, upgrades=upgrades.largeAirfield, crates={}, flavorText=flavor.alsahraairport}),
	camptiliyadeve = ZoneCommander:new({zone='Camp Tiliya Deve', side=1, level=5, upgrades=upgrades.camp, crates={}, flavorText=flavor.camptiliyadeve}),
	baladairbase = ZoneCommander:new({zone='Balad Airbase', side=1, level=3, upgrades=upgrades.largeAirfield, crates={}, flavorText=flavor.baladairbase}),
	alasadairbase = ZoneCommander:new({zone='Al-Asad Airbase', side=1, level=3, upgrades=upgrades.smallSAMSite, crates={}, flavorText=flavor.alasadairbase}),
	altajiairport = ZoneCommander:new({zone='Al-Taji Airport', side=1, level=4, upgrades=upgrades.smallAirfield, crates={}, flavorText=flavor.altajiairport}),
	altaquddumairport = ZoneCommander:new({zone='Al-Taquddum Airport', side=1, level=3, upgrades=upgrades.smallSAMSite, crates={}, flavorText=flavor.altaquddumairport}),
	alsalamairbase = ZoneCommander:new({zone='Al-Salam Airbase', side=1, level=5, upgrades=upgrades.smallAirfield, crates={}, flavorText=flavor.alsalamairbase}),
	baghdadintlairport = ZoneCommander:new({zone='Baghdad Intl Airport', side=1, level=7, upgrades=upgrades.largeSAMSite, crates={}, flavorText=flavor.baghdadintlairport}),
}

-- add unit groups to zones
zones.erbilintlairport:addGroups({
	GroupCommander:new({name='blueWP1WP2Supply', mission='supply', targetzone='Bashur Airport'}),
	GroupCommander:new({name='blueWP1WP3Supply', mission='supply', targetzone='Qayyarah Airfield West'}),
	GroupCommander:new({name='blueWP1WP4Supply', mission='supply', targetzone='K1 Base'}),
	GroupCommander:new({name='blueWP1WP5Supply', mission='supply', targetzone='Kirkuk Intl Airport'}),
	GroupCommander:new({name='blueWP1Patrol', mission='patrol', targetzone='Erbil Intl Airport'}),
	GroupCommander:new({name='blueWP1Patrol-1', mission='patrol', targetzone='Erbil Intl Airport'})
})

zones.bashurairport:addGroups({
	GroupCommander:new({name='redWP2WP1Attack', mission='attack', targetzone='Erbil Intl Airport', type='surface'}),
	GroupCommander:new({name='blueWP2WP1Supply', mission='supply', targetzone='Erbil Intl Airport'})
})

zones.qayyarahairfieldwest:addGroups({
	GroupCommander:new({name='redWP3WP1Attack', mission='attack', targetzone='Erbil Intl Airport', type='surface'})
})

zones.k1base:addGroups({
	GroupCommander:new({name='redWP4WP1Attack', mission='attack', targetzone='Erbil Intl Airport'})
})

zones.kirkukintlairport:addGroups({
	GroupCommander:new({name='redWP5WP4Attack', mission='attack', targetzone='K1 Base', type='surface'}),
	GroupCommander:new({name='blueWP5WP6Supply', mission='supply', targetzone='Sulaimaniyah Intl Airport'}),
	GroupCommander:new({name='blueWP5WP7Supply', mission='supply', targetzone='Al-Sahra Airport'}),
	GroupCommander:new({name='blueWP5WP8Supply', mission='supply', targetzone='Camp Tiliya Deve'}),
	GroupCommander:new({name='blueWP5WP1Supply', mission='supply', targetzone='Erbil Intl Airport'}),
	GroupCommander:new({name='redWP5WP4Supply', mission='supply', targetzone='K1 Base', type='surface'}),
	GroupCommander:new({name='redWP5WP3Supply', mission='supply', targetzone='Qayyarah Airfield West'}),
	GroupCommander:new({name='redWP5WP6Supply', mission='supply', targetzone='Sulaimaniyah Intl Airport'}),
	GroupCommander:new({name='redWP5WP2Supply', mission='supply', targetzone='Bashur Airport'})
	
})

zones.sulaimaniyahintlairport:addGroups({
	GroupCommander:new({name='redWP6WP1Attack', mission='attack', targetzone='Erbil Intl Airport'}),
	GroupCommander:new({name='redWP6Patrol', mission='patrol', targetzone='Sulaimaniyah Intl Airport'}),
	GroupCommander:new({name='blueWP6Patrol', mission='patrol', targetzone='Sulaimaniyah Intl Airport'})
})

zones.alsahraairport:addGroups({
	GroupCommander:new({name='blueWP7Patrol', mission='patrol', targetzone='Al-Sahra Airport'}),
	GroupCommander:new({name='redWP7WP5Attack', mission='attack', targetzone='Kirkuk Intl Airport'}),
	GroupCommander:new({name='redWP7WP3Attack', mission='attack', targetzone='Qayyarah Airfield West'}),
	GroupCommander:new({name='redWP7Patrol', mission='patrol', targetzone='Al-Sahra Airport'}),
	GroupCommander:new({name='blueWP7WP8Supply', mission='supply', targetzone='Camp Tiliya Deve'}),
	GroupCommander:new({name='blueWP7WP9Supply', mission='supply', targetzone='Balad Airbase'}),
	GroupCommander:new({name='blueWP7WP10Supply', mission='supply', targetzone='Al-Asad Airbase'}),
	GroupCommander:new({name='redWP7WP10Supply', mission='supply', targetzone='Al-Asad Airbase'}),
	GroupCommander:new({name='redWP7WP9Supply', mission='supply', targetzone='Balad Airbase'}),
	GroupCommander:new({name='redWP7WP8Supply', mission='supply', targetzone='Camp Tiliya Deve'}),
	GroupCommander:new({name='redWP7WP5Supply', mission='supply', targetzone='Kirkuk Intl Airport'}),
})

zones.camptiliyadeve:addGroups({
	GroupCommander:new({name='redWP8WP6Attack', mission='attack', targetzone='Sulaimaniyah Intl Airport', type='surface'})
})

zones.baladairbase:addGroups({
	GroupCommander:new({name='redWP9WP7Attack', mission='attack', targetzone='Al-Sahra Airport', type='surface'}),
	GroupCommander:new({name='blueWP9WP11Supply', mission='supply', targetzone='Al-Taji Airport'}),
	GroupCommander:new({name='blueWP9WP12Supply', mission='supply', targetzone='Al-Taquddum Airport'}),
	GroupCommander:new({name='blueWP9WP14Supply', mission='supply', targetzone='Baghdad Intl Airport'}),
	GroupCommander:new({name='blueWP9WP13Supply', mission='supply', targetzone='Al-Salam Airbase'}),
	GroupCommander:new({name='redWP9WP10Supply', mission='supply', targetzone='Al-Asad Airbase'}),
	GroupCommander:new({name='redWP9WP7Supply', mission='supply', targetzone='Al-Sahra Airport'}),
	GroupCommander:new({name='redWP9WP8Supply', mission='supply', targetzone='Camp Tiliya Deve'})
	
})

zones.alasadairbase:addGroups({
	GroupCommander:new({name='redWP10Patrol', mission='patrol', targetzone='Al-Asad Airbase'}),
	GroupCommander:new({name='redWP10WP5Attack', mission='attack', targetzone='Kirkuk Intl Airport'})
})

zones.altaquddumairport:addGroups({
	GroupCommander:new({name='redWP12Patrol', mission='patrol', targetzone='Al-Taquddum Airport'}),
	GroupCommander:new({name='redWP12WP7Attack', mission='attack', targetzone='Al-Sahra Airport'}),
	GroupCommander:new({name='redWP12WP9Attack', mission='attack', targetzone='Balad Airbase'}),
	GroupCommander:new({name='redWP12WP14Attack', mission='attack', targetzone='Baghdad Intl Airport', type='surface'})
})

zones.alsalamairbase:addGroups({
	GroupCommander:new({name='redWP13WP9Attack', mission='attack', targetzone='Balad Airbase'}),
	GroupCommander:new({name='redWP13WP14Attack', mission='attack', targetzone='Baghdad Intl Airport', type='surface'})
})

zones.baghdadintlairport:addGroups({
	GroupCommander:new({name='redWP14WP12Attack', mission='attack', targetzone='Al-Taquddum Airport', type='surface'}),
	GroupCommander:new({name='redWP14WP13Attack', mission='attack', targetzone='Al-Salam Airbase', type='surface'}),
	GroupCommander:new({name='redWP14WP11Attack', mission='attack', targetzone='Al-Taji Airport'}),
	GroupCommander:new({name='redWP14Patrol', mission='patrol', targetzone='Baghdad Intl Airport'}),
	GroupCommander:new({name='redWP14WP13Supply', mission='supply', targetzone='Al-Salam Airbase'}),
	GroupCommander:new({name='redWP14WP12Supply', mission='supply', targetzone='Al-Taquddum Airport'}),
	GroupCommander:new({name='redWP14WP11Supply', mission='supply', targetzone='Al-Taji Airport'}),
	GroupCommander:new({name='redWP14WP9Supply', mission='supply', targetzone='Balad Airbase'})
})

--Critical objects


--adds visible lines of "connection" between related zones
for i,v in pairs(zones) do
	bc:addZone(v)
end

bc:addConnection("Erbil Intl Airport","Bashur Airport")
bc:addConnection("Erbil Intl Airport","Qayyarah Airfield West")
bc:addConnection("Erbil Intl Airport","K1 Base")
bc:addConnection("Erbil Intl Airport","Kirkuk Intl Airport")
bc:addConnection("Kirkuk Intl Airport","Sulaimaniyah Intl Airport")
bc:addConnection("Kirkuk Intl Airport","Al-Sahra Airport")
bc:addConnection("Kirkuk Intl Airport","Camp Tiliya Deve")
bc:addConnection("Kirkuk Intl Airport","Erbil Intl Airport")
bc:addConnection("Al-Sahra Airport","Camp Tiliya Deve")
bc:addConnection("Al-Sahra Airport","Al-Asad Airbase")
bc:addConnection("Al-Sahra Airport","Balad Airbase")
bc:addConnection("Balad Airbase","Al-Taji Airport")
bc:addConnection("Balad Airbase","Baghdad Intl Airport")
bc:addConnection("Balad Airbase","Al-Taquddum Airport")
bc:addConnection("Balad Airbase","Al-Salam Airbase")
bc:addConnection("Balad Airbase","Camp Tiliya Deve")
bc:addConnection("Balad Airbase","Al-Asad Airbase")
bc:addConnection("Baghdad Intl Airport","Al-Taquddum Airport")
bc:addConnection("Baghdad Intl Airport","Al-Salam Airbase")
bc:addConnection("Baghdad Intl Airport","Al-Taji Airport")


--Mission complete msg
local checkMissionComplete = function (event, sender)
	local done = true
	for i,v in ipairs(bc:getZones()) do
		if v.side == 1 then
			done = false
			break
		end
	end
	
	if done then
		trigger.action.setUserFlag("ending", true)
		timer.scheduleFunction(endMission, {}, timer.getTime() + 20)
	end
end

for i,v in ipairs(bc:getZones()) do
	v:registerTrigger('lost', checkMissionComplete, 'missioncompleted')
end

--Disabling/losing zones (grayed out on map)

--Add Despawn Menu Capability

-- Setup Script: Add the Despawn Active AI menu item
local groupNames = {
    "AWACS",
    "CAP",
    "CAS",
    "SEAD",
    "BOMBING"
}

-- Debugging: Confirm the group names being passed to the AIManagement class
--trigger.action.outTextForCoalition(2, "Sending group names: " .. table.concat(groupNames, ", "), 10)

-- Store the group names in the AIManagement class and build the menu
AIManagement.storeGroupNames(groupNames)




--F10 Menu Items
local upgradeMenu = nil
bc:registerShopItem('supplies', 'Resupply friendly Zone', 200, function(sender)
	if upgradeMenu then
		return 'Choose zone from F10 menu'
	end
	
	local upgradeZone = function(target)
		if upgradeMenu then
			local zn = bc:getZoneByName(target)
			if zn and zn.side==2 then
				zn:upgrade()
			else
				return 'Zone not friendly'
			end
			
			upgradeMenu = nil
		end
	end
	
	upgradeMenu = bc:showTargetZoneMenu(2, 'Select Zone to resupply', upgradeZone, 2)
	
	trigger.action.outTextForCoalition(2, 'Supplies prepared. Choose zone from F10 menu', 15)
end,
function(sender, params)
	if params.zone and params.zone.side == 2 then
		params.zone:upgrade()
	else
		return 'Can only target friendly zone'
	end
end)

Group.getByName('CAP'):destroy()
bc:registerShopItem('cap', 'CAP (F-15C)', 150, function(sender) 
	local grname = 'CAP'
	local gr = Group.getByName(grname)
	if Utils.isGroupActive(gr) then 
		return 'CAP mission still in progress'
	end
	mist.respawnGroup(grname, true)
end)

local spawnAwacs = function(sender) 
	local gr = Group.getByName('AWACS')
	if Utils.isGroupActive(gr) then 
		return 'Overlord still active on 350.00 MHz AM'
	end
	mist.respawnGroup('AWACS', true)
	trigger.action.outTextForCoalition(2,'Overlord active on 350.00 MHz AM',15)
end
Group.getByName('AWACS'):destroy()
bc:registerShopItem('AWACS', 'AWACS (E-3A)', 100, spawnAwacs, spawnAwacs)

Group.getByName('CAS'):destroy()
local casTargetMenu = nil
bc:registerShopItem('cas', 'CAS (A-10CII)', 400, function(sender) 
	local gr = Group.getByName('CAS')
	if Utils.isGroupActive(gr) then 
		return 'Ground attack mission still in progress'
	end
	
	mist.respawnGroup('CAS', true)
	
	if casTargetMenu then
		return 'Choose target zone from F10 menu'
	end
	
	local launchAttack = function(target)
		if casTargetMenu then
			if Group.getByName('CAS') then
				local err = bc:engageZone(target, 'CAS')
				if err then
					return err
				end
				
				trigger.action.outTextForCoalition(2, 'A-10CII Warthogs engaging groups at '..target, 15)
			else
				trigger.action.outTextForCoalition(2, 'Group has left the area or has been destroyed', 15)
			end
			
			casTargetMenu = nil
		end
	end
	
	casTargetMenu = bc:showTargetZoneMenu(2, 'CAS Target', launchAttack, 1)
	
	trigger.action.outTextForCoalition(2, 'A-10CII Warthogs on route. Choose target zone from F10 menu', 15)
end,
function (sender, params)
	if params.zone and params.zone.side == 1 then
		local gr = Group.getByName('CAS')
		if Utils.isGroupActive(gr) then 
			return 'Ground attack mission still in progress'
		end
		
		mist.respawnGroup('CAS', true)
		mist.scheduleFunction(function(target)
			if Group.getByName('CAS') then
				local err = bc:engageZone(target, 'CAS')
				if err then
					return err
				end
				
				trigger.action.outTextForCoalition(2, 'A-10CII Warthogs engaging groups at '..target, 15)
			end
		end,{params.zone.zone},timer.getTime()+2)
	else
		return 'Can only target enemy zone'
	end
end)

Group.getByName('BOMBING'):destroy()
local bomberTargetMenu = nil
bc:registerShopItem('bomb', 'Bombing run (F-15E)', 600, function(sender) 
	local gr = Group.getByName('BOMBING')
	if Utils.isGroupActive(gr) then 
		return 'Bombing run still in progress'
	end
	
	mist.respawnGroup('BOMBING', true)
	
	if bomberTargetMenu then
		return 'Choose target zone from F10 menu'
	end
	
	local launchAttack = function(target)
		if bomberTargetMenu then
			local bomb = Group.getByName('BOMBING')
			if bomb then
				local err = bc:engageZone(target, 'BOMBING')
				if err then
					return err
				end
				
				trigger.action.outTextForCoalition(2, 'F-15E Mudhen engaging groups at '..target, 15)
			else
				trigger.action.outTextForCoalition(2, 'Group has left the area or has been destroyed', 15)
			end
			
			bomberTargetMenu = nil
		end
	end
	
	bomberTargetMenu = bc:showTargetZoneMenu(2, 'Bombing run Target', launchAttack, 1)
	
	trigger.action.outTextForCoalition(2, 'F-15E Mudhen on route. Choose target zone from F10 menu', 15)
end,
function (sender, params)
	if params.zone and params.zone.side == 1 then
		local gr = Group.getByName('BOMBING')
		if Utils.isGroupActive(gr) then 
			return 'Bombing run still in progress'
		end
		
		mist.respawnGroup('BOMBING', true)
		
		mist.scheduleFunction(function(target)
			local bomb = Group.getByName('BOMBING')
			if bomb then
				local err = bc:engageZone(target, 'BOMBING', AI.Task.WeaponExpend.ALL)
				if err then
					return err
				end
				
				trigger.action.outTextForCoalition(2, 'F-15E Mudhen engaging groups at '..target, 15)
			end
		end,{params.zone.zone},timer.getTime()+2)
	else
		return 'Can only target enemy zone'
	end
end)

Group.getByName('SEAD'):destroy()
local seadTargetMenu = nil
bc:registerShopItem('sead', 'SEAD (F/A-18C)', 150, function(sender) 
	local gr = Group.getByName('SEAD')
	if Utils.isGroupActive(gr) then 
		return 'SEAD mission still in progress'
	end
	mist.respawnGroup('SEAD', true)
	
	if seadTargetMenu then
		return 'Choose target zone from F10 menu'
	end
	
	local launchAttack = function(target)
		if Group.getByName('SEAD') then
			local err = bc:engageZone(target, 'SEAD', AI.Task.WeaponExpend.ALL)
			if err then
				return err
			end
			
			trigger.action.outTextForCoalition(2, 'F/A-18c Hornets engaging SEAD targets at '..target, 15)
		else
			trigger.action.outTextForCoalition(2, 'Group has left the area or has been destroyed', 15)
		end
		
		seadTargetMenu = nil
	end
	
	seadTargetMenu = bc:showTargetZoneMenu(2, 'SEAD Target', launchAttack, 1)
	
	trigger.action.outTextForCoalition(2, 'F/A-18c Hornets on route. Choose target zone from F10 menu', 15)
end,
function (sender, params)
	if params.zone and params.zone.side == 1 then
		local gr = Group.getByName('SEAD')
		if Utils.isGroupActive(gr) then 
			return 'SEAD mission still in progress'
		end
		
		mist.respawnGroup('SEAD', true)
		mist.scheduleFunction(function(target)
			if Group.getByName('SEAD') then
				local err = bc:engageZone(target, 'SEAD')
				if err then
					return err
				end
				
				trigger.action.outTextForCoalition(2, 'F/A-a8c Hornets engaging SEAD targets at '..target, 15)
			end
		end,{params.zone.zone},timer.getTime()+2)
	else
		return 'Can only target enemy zone'
	end
end)

Group.getByName('jtacDrone-Lase-1688'):destroy()
local jtacTargetMenu = nil
drone = JTAC:new({name = 'jtacDrone-Lase-1688'})
bc:registerShopItem('jtac', 'MQ-9 Reaper JTAC mission', 100, function(sender)
	
	if jtacTargetMenu then
		return 'Choose target zone from F10 menu'
	end
	
	local spawnAndOrbit = function(target)
		if jtacTargetMenu then
			local zn = bc:getZoneByName(target)
			drone:deployAtZone(zn)
			drone:showMenu()
			trigger.action.outTextForCoalition(2, 'Reaper drone deployed over '..target, 15)
			jtacTargetMenu = nil
		end
	end
	
	jtacTargetMenu = bc:showTargetZoneMenu(2, 'Deploy JTAC', spawnAndOrbit, 1)
	
	trigger.action.outTextForCoalition(2, 'Choose which zone to deploy JTAC at from F10 menu', 15)
end,
function(sender, params)
	if params.zone and params.zone.side == 1 then
		drone:deployAtZone(params.zone)
		drone:showMenu()
		trigger.action.outTextForCoalition(2, 'Reaper drone deployed over '..params.zone.zone, 15)
	else
		return 'Can only target enemy zone'
	end
end)

local smoketargets = function(tz)
	local units = {}
	for i,v in pairs(tz.built) do
		local g = Group.getByName(v)
		for i2,v2 in ipairs(g:getUnits()) do
			table.insert(units, v2)
		end
	end
	
	local tgts = {}
	for i=1,3,1 do
		if #units > 0 then
			local selected = math.random(1,#units)
			table.insert(tgts, units[selected])
			table.remove(units, selected)
		end
	end
	
	for i,v in ipairs(tgts) do
		local pos = v:getPosition().p
		trigger.action.smoke(pos, 1)
	end
end

local smokeTargetMenu = nil
bc:registerShopItem('smoke', 'Smoke markers', 20, function(sender)
	if smokeTargetMenu then
		return 'Choose target zone from F10 menu'
	end
	
	local launchAttack = function(target)
		if smokeTargetMenu then
			local tz = bc:getZoneByName(target)
			smoketargets(tz)
			smokeTargetMenu = nil
			trigger.action.outTextForCoalition(2, 'Targets marked with RED smoke at '..target, 15)
		end
	end
	
	smokeTargetMenu = bc:showTargetZoneMenu(2, 'Smoke marker target', launchAttack, 1)
	
	trigger.action.outTextForCoalition(2, 'Choose target zone from F10 menu', 15)
end,
function(sender, params)
	if params.zone and params.zone.side == 1 then
		smoketargets(params.zone)
		trigger.action.outTextForCoalition(2, 'Targets marked with RED smoke at '..params.zone.zone, 15)
	else
		return 'Can only target enemy zone'
	end
end)

Group.getByName('Growler'):destroy()
local jamMenu = nil
bc:registerShopItem('jam', 'Jam radars at zone', 500, function(sender)
	local gr = Group.getByName('Growler')
	if Utils.isGroupActive(gr) then 
		return 'Jamming mission still in progress'
	end
	
	mist.respawnGroup('Growler', true)
	
	if jamMenu then
		return 'Choose target zone from F10 menu'
	end
	
	local startJam = function(target)
		if jamMenu then
			bc:jamRadarsAtZone('Growler', target)
			jamMenu = nil
			trigger.action.outTextForCoalition(2, 'Growler jamming radars at '..target, 15)
		end
	end
	
	jamMenu = bc:showTargetZoneMenu(2, 'Jamming target', startJam, 1)
	trigger.action.outTextForCoalition(2, 'Choose target zone from F10 menu', 15)
end,
function(sender, params)
	if params.zone and params.zone.side == 1 then
		local gr = Group.getByName('Growler')
		if Utils.isGroupActive(gr) then 
			return 'Jamming mission still in progress'
		end
		
		mist.respawnGroup('Growler', true)
		
		mist.scheduleFunction(function(target)
			local ew = Group.getByName('Growler')
			if ew then
				local err = bc:jamRadarsAtZone('Growler', target)
				if err then
					return err
				end
				
				trigger.action.outTextForCoalition(2, 'Growler jamming radars at '..target, 15)
			end
		end,{params.zone.zone},timer.getTime()+2)
		
	else
		return 'Can only target enemy zone'
	end
end)

tanksMenu = nil
bc:registerShopItem('armor', 'Deploy armor (for combined arms)', 100, function(sender)
	
	if tanksMenu then
		return 'Choose deploy zone from F10 menu'
	end
	
	local deployTanks = function(target)
		if tanksMenu then
		
			local zn = CustomZone:getByName(target)
			zn:spawnGroup('ca-tanks')
			
			tanksMenu = nil
			trigger.action.outTextForCoalition(2, 'Friendly armor deployed at '..target, 15)
		end
	end
	
	tanksMenu = bc:showTargetZoneMenu(2, 'Deploy armor (Choose friendly zone)', deployTanks, 2)
	trigger.action.outTextForCoalition(2, 'Choose deploy zone from F10 menu', 15)
end,
function(sender, params)
	if params.zone and params.zone.side == 2 then
		
		local zn = CustomZone:getByName(params.zone.zone)
		zn:spawnGroup('ca-tanks')
		trigger.action.outTextForCoalition(2, 'Friendly armor deployed at '..params.zone.zone, 15)
	else
		return 'Can only deploy at friendly zone'
	end
end)

artyMenu = nil
bc:registerShopItem('artillery', 'Deploy artillery (for combined arms)', 100, function(sender)
	
	if artyMenu then
		return 'Choose deploy zone from F10 menu'
	end
	
	local deployArty = function(target)
		if artyMenu then
		
			local zn = CustomZone:getByName(target)
			zn:spawnGroup('ca-arty')
			
			artyMenu = nil
			trigger.action.outTextForCoalition(2, 'Friendly artillery deployed at '..target, 15)
		end
	end
	
	artyMenu = bc:showTargetZoneMenu(2, 'Deploy artillery (Choose friendly zone)', deployArty, 2)
	trigger.action.outTextForCoalition(2, 'Choose deploy zone from F10 menu', 15)
end,
function(sender, params)
	if params.zone and params.zone.side == 2 then
		
		local zn = CustomZone:getByName(params.zone.zone)
		zn:spawnGroup('ca-arty')
		trigger.action.outTextForCoalition(2, 'Friendly artillery deployed at '..params.zone.zone, 15)
	else
		return 'Can only deploy at friendly zone'
	end
end)

reconMenu = nil
bc:registerShopItem('recon', 'Deploy recon group (for combined arms)', 50, function(sender)
	
	if reconMenu then
		return 'Choose deploy zone from F10 menu'
	end
	
	local deployRecon = function(target)
		if reconMenu then
		
			local zn = CustomZone:getByName(target)
			zn:spawnGroup('ca-recon')
			
			reconMenu = nil
			trigger.action.outTextForCoalition(2, 'Friendly recon group deployed at '..target, 15)
		end
	end
	
	reconMenu = bc:showTargetZoneMenu(2, 'Deploy recon group (Choose friendly zone)', deployRecon, 2)
	trigger.action.outTextForCoalition(2, 'Choose deploy zone from F10 menu', 15)
end,
function(sender, params)
	if params.zone and params.zone.side == 2 then
		
		local zn = CustomZone:getByName(params.zone.zone)
		zn:spawnGroup('ca-recon')
		trigger.action.outTextForCoalition(2, 'Friendly recon group deployed at '..params.zone.zone, 15)
	else
		return 'Can only deploy at friendly zone'
	end
end)

airdefMenu = nil
bc:registerShopItem('airdef', 'Deploy air defence (for combined arms)', 150, function(sender)
	
	if airdefMenu then
		return 'Choose deploy zone from F10 menu'
	end
	
	local deployAirDef = function(target)
		if airdefMenu then
		
			local zn = CustomZone:getByName(target)
			zn:spawnGroup('ca-airdef')
			
			airdefMenu = nil
			trigger.action.outTextForCoalition(2, 'Friendly air defence deployed at '..target, 15)
		end
	end
	
	airdefMenu = bc:showTargetZoneMenu(2, 'Deploy air defence (Choose friendly zone)', deployAirDef, 2)
	trigger.action.outTextForCoalition(2, 'Choose deploy zone from F10 menu', 15)
end,
function(sender, params)
	if params.zone and params.zone.side == 2 then
		
		local zn = CustomZone:getByName(params.zone.zone)
		zn:spawnGroup('ca-airdef')
		trigger.action.outTextForCoalition(2, 'Friendly air defence deployed at '..params.zone.zone, 15)
	else
		return 'Can only deploy at friendly zone'
	end
end)

bc:addShopItem(2, 'supplies', -1)
bc:addShopItem(2, 'jtac', -1)
bc:addShopItem(2, 'smoke', -1)
bc:addShopItem(2, 'jam', -1)

bc:addShopItem(2, 'cap', -1)
bc:addShopItem(2, 'AWACS', -1)
bc:addShopItem(2, 'cas', -1)
bc:addShopItem(2, 'bomb', -1)
bc:addShopItem(2, 'sead', -1)

bc:addShopItem(2, 'armor', -1)
bc:addShopItem(2, 'artillery', -1)
bc:addShopItem(2, 'recon', -1)
bc:addShopItem(2, 'airdef', -1)

supplyZones = {
	'Erbil Intl Airport',
	'Bashur Airport',
	'Qayyarah Airfield West',
	'K1 Base',
	'Kirkuk Intl Airport',
	'Sulaimaniyah Intl Airport',
	'Al-Sahra Airport',
	'Camp Tiliya Deve',
	'Balad Airbase',
	'Al-Asad Airbase',
	'Al-Taji Airport',
	'Al-Taquddum Airport',
	'Al-Salam Airbase',
	'Baghdad Intl Airport'
	}

--logistics commander
lc = LogisticCommander:new({battleCommander = bc, supplyZones = supplyZones})
lc:init()

--Credit amounts for kills
bc:loadFromDisk() --will load and overwrite default zone levels, sides, funds and available shop items
bc:init()
bc:startRewardPlayerContribution(15,{infantry = 10, ground = 20, sam = 40, airplane = 50, ship = 250, helicopter=50, crate=200, rescue = 100})
HercCargoDropSupply.init(bc)

--GlobalSettings.defaultRespawns[1]['supply'] = { dead=60*60, hangar=30*60, preparing=5*60}
GlobalSettings.setDifficultyScaling(1.4,1)

--create event commander
evc = EventCommander:new({ decissionFrequency=15*60, decissionVariance=15*60, skipChance = 5}) --decissionFrequency=30*60, decissionVariance=30*60, skipChance = 10
evc:init()

--MIST spawns of events
Group.getByName('evt-cargointercept1'):destroy()
Group.getByName('evt-cargointercept2'):destroy()
Group.getByName('evt-cargointercept3'):destroy()

local cargoDieEvent = nil
evc:addEvent({
	id='cargointercept',
	action = function()
	
		local planes = {'evt-cargointercept1','evt-cargointercept2','evt-cargointercept3'}
		local choice = math.random(1,#planes)
		
		mist.respawnGroup(planes[choice], true)
		
		local cargoDie = function(event)
			if event.id==30 then
				if event.initiator and event.initiator.getName then
					local name = event.initiator:getName()
					if type(name)=="string" and name:find('^evt%-cargointercept') then
						mist.removeEventHandler(cargoDieEvent)
						cargoDieEvent = nil
						trigger.action.outTextForCoalition(2,'Enemy cargo plane destroyed.\n+500 credits',15)
						bc:addFunds(2,500)
					end
				end
			end
		end
		cargoDieEvent = mist.addEventHandler(cargoDie)
	end,
	canExecute = function()
		if math.random(1,100) < 25 then return false end
		
		if bc:getZoneByName('Erbil Intl Airport').side ~= 1 then return false end
		
		if Group.getByName('evt-cargointercept1') then return false end
		if Group.getByName('evt-cargointercept2') then return false end
		if Group.getByName('evt-cargointercept3') then return false end
		
		return true
	end
})



Group.getByName('evt-bomber'):destroy()
evc:addEvent({
	id='bomb',
	action = function()
		mist.respawnGroup('evt-bomber', true)
	end,
	canExecute = function()
		local gr = Group.getByName('evt-bomber')
		if gr then return false end
		
		local triggers = {'Erbil Intl Airport'}
		for _,v in ipairs(triggers) do
			if bc:getZoneByName(v).side == 2 then
				return true
			end
		end
		
		return false
	end
})

function startBomberAttack() -- called from bomber groups waypoint actions
	local tgts = {
		'Erbil Intl Airport',
		'Bashur Airport',
		'Qayyarah Airfield West',
		'K1 Base',
		'Kirkuk Intl Airport',
		'Sulaimaniyah Intl Airport',
		'Al-Sahra Airport',
		'Camp Tiliya Deve',
		'Balad Airbase',
		'Al-Asad Airbase',
		'Al-Taji Airport',
		'Al-Taquddum Airport',
		'Al-Salam Airbase',
		'Baghdad Intl Airport'
	}
	
	local validtgts = {}
	for _,v in ipairs(tgts) do
		if bc:getZoneByName(v).side == 2 then
			table.insert(validtgts, v)
		end
	end
	
	if #validtgts ~= 0 then
		local die = math.random(1,#validtgts)
		local choice = validtgts[die]
		
		if Group.getByName('evt-bomber') then
			bc:engageZone(choice, 'evt-bomber',  AI.Task.WeaponExpend.ALL)
		end
	end
end

Group.getByName('evt-sead'):destroy()
evc:addEvent({
	id='sead',
	action = function()
		mist.respawnGroup('evt-sead', true)
	end,
	canExecute = function()
		local gr = Group.getByName('evt-sead')
		if gr then return false end
		
		local triggers = {'Erbil Intl Airport'}
		for _,v in ipairs(triggers) do
			if bc:getZoneByName(v).side == 2 then
				return true
			end
		end
		
		return false
	end
})

function startSEADAttack() -- called from SEAD groups waypoint actions
	local tgts = {
		'Erbil Intl Airport',
		'Bashur Airport',
		'Qayyarah Airfield West',
		'K1 Base',
		'Kirkuk Intl Airport',
		'Sulaimaniyah Intl Airport',
		'Al-Sahra Airport',
		'Camp Tiliya Deve',
		'Balad Airbase',
		'Al-Asad Airbase',
		'Al-Taji Airport',
		'Al-Taquddum Airport',
		'Al-Salam Airbase',
		'Baghdad Intl Airport'
	}
	
	local validtgts = {}
	for _,v in ipairs(tgts) do
		if bc:getZoneByName(v).side == 2 then
			table.insert(validtgts, v)
		end
	end
	
	if #validtgts ~= 0 then
		local die = math.random(1,#validtgts)
		local choice = validtgts[die]
		
		if Group.getByName('evt-sead') then
			bc:engageZone(choice, 'evt-sead',  AI.Task.WeaponExpend.ALL)
		end
	end
end

Group.getByName('evt-cas'):destroy()
evc:addEvent({
	id='cas',
	action = function()
		mist.respawnGroup('evt-cas', true)
	end,
	canExecute = function()
		local gr = Group.getByName('evt-cas')
		if gr then return false end
		
		local triggers = {'Erbil Intl Airport'}
		for _,v in ipairs(triggers) do
			if bc:getZoneByName(v).side == 2 then
				return true
			end
		end
		
		return false
	end
})

function startCASAttack() -- called from CAS groups waypoint actions
	local tgts = {
		'Erbil Intl Airport',
		'Bashur Airport',
		'Qayyarah Airfield West',
		'K1 Base',
		'Kirkuk Intl Airport',
		'Sulaimaniyah Intl Airport',
		'Al-Sahra Airport',
		'Camp Tiliya Deve',
		'Balad Airbase',
		'Al-Asad Airbase',
		'Al-Taji Airport',
		'Al-Taquddum Airport',
		'Al-Salam Airbase',
		'Baghdad Intl Airport'
	}
	
	local validtgts = {}
	for _,v in ipairs(tgts) do
		if bc:getZoneByName(v).side == 2 then
			table.insert(validtgts, v)
		end
	end
	
	if #validtgts ~= 0 then
		local die = math.random(1,#validtgts)
		local choice = validtgts[die]
		
		if Group.getByName('evt-cas') then
			bc:engageZone(choice, 'evt-cas',  AI.Task.WeaponExpend.ALL)
		end
	end
end

Group.getByName('evt-cas2'):destroy()
evc:addEvent({
	id='cas2',
	action = function()
		mist.respawnGroup('evt-cas2', true)
	end,
	canExecute = function()
		local gr = Group.getByName('evt-cas2')
		if gr then return false end
		
		local triggers = {'Erbil Intl Airport'}
		for _,v in ipairs(triggers) do
			if bc:getZoneByName(v).side == 2 then
				return true
			end
		end
		
		return false
	end
})

function startCAS2Attack() -- called from CAS groups waypoint actions
	local tgts = {
		'Erbil Intl Airport',
		'Bashur Airport',
		'Qayyarah Airfield West',
		'K1 Base',
		'Kirkuk Intl Airport',
		'Sulaimaniyah Intl Airport',
		'Al-Sahra Airport',
		'Camp Tiliya Deve',
		'Balad Airbase',
		'Al-Asad Airbase',
		'Al-Taji Airport',
		'Al-Taquddum Airport',
		'Al-Salam Airbase',
		'Baghdad Intl Airport'
	}
	
	local validtgts = {}
	for _,v in ipairs(tgts) do
		if bc:getZoneByName(v).side == 2 then
			table.insert(validtgts, v)
		end
	end
	

	if #validtgts ~= 0 then
		local die = math.random(1,#validtgts)
		local choice = validtgts[die]
		
		if Group.getByName('evt-cas2') then
			bc:engageZone(choice, 'evt-cas2',  AI.Task.WeaponExpend.ALL)
		end
	end
end

-- System msgs for events triggered
mc = MissionCommander:new({side = 2, battleCommander = bc, checkFrequency = 20}) --was checkFrequency = 60
mc:trackMission({
	title = "Intercept cargo plane",
	description = "Find and destroy the enemy cargo plane.",
	messageStart = "New mission: Intercept cargo plane",
	messageEnd = "Mission ended: Intercept cargo plane",
	startAction = function() trigger.action.outSoundForCoalition(2,"ding.ogg") end,
	endAction = function() trigger.action.outSoundForCoalition(2,"cancel.ogg") end,
	isActive = function()
		if Group.getByName('evt-cargointercept1') then return true end
		if Group.getByName('evt-cargointercept2') then return true end
		if Group.getByName('evt-cargointercept3') then return true end
		
		return false
	end
})

mc:trackMission({
	title = "Intercept Bomber",
	description = "Enemy bombers spotted to the south-east\nDestroy them before they get in range.",
	messageStart = "New mission: Intercept Bomber",
	messageEnd = "Mission ended: Intercept Bomber",
	startAction = function() trigger.action.outSoundForCoalition(2,"ding.ogg") end,
	endAction = function() trigger.action.outSoundForCoalition(2,"cancel.ogg") end,
	isActive = function()
		local gr = Group.getByName('evt-bomber')
		if gr then return true else return false end
	end
})

mc:trackMission({
	title = "Intercept enemy airstrike",
	description = "Enemy aircraft conducting an airstrike from the west\nDestroy them before they get in range.",
	messageStart = "New mission: Intercept enemy airstrike",
	messageEnd = "Mission ended: Intercept enemy airstrike",
	startAction = function() trigger.action.outSoundForCoalition(2,"ding.ogg") end,
	endAction = function() trigger.action.outSoundForCoalition(2,"cancel.ogg") end,
	isActive = function()
		local gr = Group.getByName('evt-cas')
		if gr then return true else return false end
	end
})

mc:trackMission({
	title = "Intercept enemy airstrike",
	description = "Enemy aircraft conducting an airstrike from the west\nDestroy them before they get in range.",
	messageStart = "New mission: Intercept enemy airstrike",
	messageEnd = "Mission ended: Intercept enemy airstrike",
	startAction = function() trigger.action.outSoundForCoalition(2,"ding.ogg") end,
	endAction = function() trigger.action.outSoundForCoalition(2,"cancel.ogg") end,
	isActive = function()
		local gr = Group.getByName('evt-cas2')
		if gr then return true else return false end
	end
})

mc:trackMission({
	title = "Intercept enemy SEAD/DEAD attack",
	description = "Enemy aircraft conducting an SEAD/DEAD from the east\nDestroy them before they get in range.",
	messageStart = "New mission: Intercept enemy SEAD/DEAD",
	messageEnd = "Mission ended: Intercept enemy SEAD/DEAD",
	startAction = function() trigger.action.outSoundForCoalition(2,"ding.ogg") end,
	endAction = function() trigger.action.outSoundForCoalition(2,"cancel.ogg") end,
	isActive = function()
		local gr = Group.getByName('evt-sead')
		if gr then return true else return false end
	end
})

resupplyTarget = nil
mc:trackMission({
	title = function() return "Resupply "..resupplyTarget end,
	description = function() return "Deliver supplies to "..resupplyTarget end,
	messageStart = function() return "New mission: Resupply "..resupplyTarget end,
	messageEnd = function() return "Mission ended: Resupply "..resupplyTarget end,
	startAction = function() trigger.action.outSoundForCoalition(2,"ding.ogg") end,
	endAction = function() 
		resupplyTarget = nil
		trigger.action.outSoundForCoalition(2,"cancel.ogg")
	end,
	isActive = function()
		if not resupplyTarget then return false end
		
		local targetzn = bc:getZoneByName(resupplyTarget)
		return targetzn:canRecieveSupply()
	end
})

attackTarget = nil
mc:trackMission({
	title = function() return "Attack "..attackTarget end,
	description = function() return "Destroy enemy forces at "..attackTarget end,
	messageStart = function() return "New mission: Attack "..attackTarget end,
	messageEnd = function() return "Mission ended: Attack "..attackTarget end,
	startAction = function() trigger.action.outSoundForCoalition(2,"ding.ogg") end,
	endAction = function() 
		attackTarget = nil 
		trigger.action.outSoundForCoalition(2,"cancel.ogg")
	end,
	isActive = function()
		if not attackTarget then return false end
		
		local targetzn = bc:getZoneByName(attackTarget)
		return targetzn.side == 1
	end
})

captureTarget = nil
mc:trackMission({
	title = function() return "Capture "..captureTarget end,
	description = function() return captureTarget.." is neutral. Capture it by delivering supplies" end,
	messageStart = function() return "New mission: Capture "..captureTarget end,
	messageEnd = function() return "Mission ended: Capture "..captureTarget end,
	startAction = function() trigger.action.outSoundForCoalition(2,"ding.ogg") end,
	endAction = function() 
		captureTarget = nil 
		trigger.action.outSoundForCoalition(2,"cancel.ogg")
	end,
	isActive = function()
		if not captureTarget then return false end
		
		local targetzn = bc:getZoneByName(captureTarget)
		return targetzn.side == 0 and targetzn.active
	end
})

--Functions/
	
function addFunds500()
	bc:addFunds(2,500)
	end
	
function addRestartCredits()
		bc:addFunds(2,500)
		end
	
function endMission()
	--trigger.action.outTextForCoalition(2, 'file path is '..pathofFile, 420)
	--io.close(pathofFile)
	--timer.scheduleFunction(delFile, {}, timer.getTime() + 10)
	--os.remove(pathofFile)
	trigger.action.setUserFlag("endMission", true)
	end
	
function generateCaptureMission()
	if captureTarget ~= nil then return end
		
	local validzones = {}
	for _,v in ipairs(bc.zones) do
		if v.side == 0 and v.active then
			table.insert(validzones, v.zone)
		end
	end
	
	if #validzones == 0 then return end
	
	local choice = math.random(1, #validzones)
	if validzones[choice] then
		captureTarget = validzones[choice]
		return true
	end
end

function generateAttackMission()
	if attackTarget ~= nil then return end
		
	local validzones = {}
	for _,v in ipairs(bc.connections) do
		local to = bc:getZoneByName(v.to)
		local from = bc:getZoneByName(v.from)
		
		if from.side ~= to.side and from.side ~= 0  and to.side ~= 0 and from.active and to.active then
			if from.side == 1 then
				table.insert(validzones, from.zone)
			elseif to.side == 1 then
				table.insert(validzones, to.zone)
			end
		end
	end
	
	if #validzones == 0 then return end
	
	local choice = math.random(1, #validzones)
	if validzones[choice] then
		attackTarget = validzones[choice]
		return true
	end
end

function generateSupplyMission()
	if resupplyTarget ~= nil then return end
		
	local validzones = {}
	for _,v in ipairs(bc.zones) do
		if v.side == 2 and v:canRecieveSupply() then
			table.insert(validzones, v.zone)
		end
	end
	
	if #validzones == 0 then return end
	
	local choice = math.random(1, #validzones)
	if validzones[choice] then
		resupplyTarget = validzones[choice]
		return true
	end
end

timer.scheduleFunction(function(_, time)
	if generateCaptureMission() then
		return time+300
	else
		return time+120
	end
end, {}, timer.getTime() + 20)

timer.scheduleFunction(function(_, time)
	if generateAttackMission() then
		return time+300
	else
		return time+120
	end
end, {}, timer.getTime() + 40)

timer.scheduleFunction(function(_, time)
	if generateSupplyMission() then
		return time+480
	else
		return time+240
	end
end, {}, timer.getTime() + 60)

mc:init()